@@ -2,9 +2,9 @@ from dataclasses import dataclass, field
 from typing import Dict, List, Generic, TypeVar
 from abc import ABC, abstractmethod
 
-from src.request.requestParams import RequestParams
-from src.services.jwt.jwtPayload import JWTPayload
-from src.providers.logger.ILogAction import ILogAction
+from nerualpha.request.requestParams import RequestParams
+from nerualpha.services.jwt.jwtPayload import JWTPayload
+from nerualpha.providers.logger.ILogAction import ILogAction
 
 
 #interface
