@@ -2,9 +2,9 @@ from dataclasses import dataclass, field
 from typing import Dict, List, Generic, TypeVar
 from abc import ABC, abstractmethod
 
-from src.providers.state.state import State
-from src.request.IRequest import IRequest
-from src.session.neruSession import NeruSession
+from nerualpha.providers.state.state import State
+from nerualpha.request.IRequest import IRequest
+from nerualpha.session.neruSession import NeruSession
 
 
 #interface
