@@ -2,15 +2,15 @@ from dataclasses import dataclass, field
 from typing import Dict, List, Generic, TypeVar
 from abc import ABC, abstractmethod
 
-from src.IBridge import IBridge
-from src.request.requestMethods import RequestMethods
-from src.request.requestParams import RequestParams
-from src.services.config.IConfig import IConfig
-from src.session.ISession import ISession
-from src.providers.logger.ILogContext import ILogContext
-from src.providers.logger.ILogger import ILogger
-from src.providers.logger.logAction import LogAction
-from src.providers.logger.sourceTypes import SourceTypes
+from nerualpha.IBridge import IBridge
+from nerualpha.request.requestMethods import RequestMethods
+from nerualpha.request.requestParams import RequestParams
+from nerualpha.services.config.IConfig import IConfig
+from nerualpha.session.ISession import ISession
+from nerualpha.providers.logger.ILogContext import ILogContext
+from nerualpha.providers.logger.ILogger import ILogger
+from nerualpha.providers.logger.logAction import LogAction
+from nerualpha.providers.logger.sourceTypes import SourceTypes
 
 @dataclass
 class Logger(ILogger):
