@@ -2,7 +2,7 @@ from dataclasses import dataclass, field
 from typing import Dict, List, Generic, TypeVar
 from abc import ABC, abstractmethod
 
-from src.providers.scheduler.contracts.ICancelSchedulePayload import ICancelSchedulePayload
+from nerualpha.providers.scheduler.contracts.ICancelSchedulePayload import ICancelSchedulePayload
 
 @dataclass
 class CancelSchedulePayload(ICancelSchedulePayload):
