@@ -2,14 +2,14 @@ from dataclasses import dataclass, field
 from typing import Dict, List, Generic, TypeVar
 from abc import ABC, abstractmethod
 
-from src.session.requestInterface import RequestInterface
-from src.session.requestInterfaceForCallbacks import RequestInterfaceForCallbacks
-from src.providers.vonageAPI.contracts.invokePayload import InvokePayload
-from src.providers.voice.contracts.vapiCreateCallPayload import VapiCreateCallPayload
-from src.providers.voice.conversation import Conversation
-from src.providers.voice.contracts.IVapiEventParams import IVapiEventParams
-from src.providers.voice.contracts.IPhoneContact import IPhoneContact
-from src.providers.voice.contracts.IChannelPhoneEndpoint import IChannelPhoneEndpoint
+from nerualpha.session.requestInterface import RequestInterface
+from nerualpha.session.requestInterfaceForCallbacks import RequestInterfaceForCallbacks
+from nerualpha.providers.vonageAPI.contracts.invokePayload import InvokePayload
+from nerualpha.providers.voice.contracts.vapiCreateCallPayload import VapiCreateCallPayload
+from nerualpha.providers.voice.conversation import Conversation
+from nerualpha.providers.voice.contracts.IVapiEventParams import IVapiEventParams
+from nerualpha.providers.voice.contracts.IPhoneContact import IPhoneContact
+from nerualpha.providers.voice.contracts.IChannelPhoneEndpoint import IChannelPhoneEndpoint
 
 
 #interface
