@@ -2,7 +2,7 @@ from dataclasses import dataclass, field
 from typing import Dict, List, Generic, TypeVar
 from abc import ABC, abstractmethod
 
-from src.providers.voice.contracts.ICreateConversationPayload import ICreateConversationPayload
+from nerualpha.providers.voice.contracts.ICreateConversationPayload import ICreateConversationPayload
 
 @dataclass
 class CreateConversationPayload(ICreateConversationPayload):
