@@ -2,7 +2,7 @@ from dataclasses import dataclass, field
 from typing import Dict, List, Generic, TypeVar
 from abc import ABC, abstractmethod
 
-from src.providers.voice.contracts.ILegId import ILegId
+from nerualpha.providers.voice.contracts.ILegId import ILegId
 
 @dataclass
 class LegId(ILegId):
