@@ -2,9 +2,9 @@ from dataclasses import dataclass, field
 from typing import Dict, List, Generic, TypeVar
 from abc import ABC, abstractmethod
 
-from src.providers.voice.contracts.IOnInboundCallPayload import IOnInboundCallPayload
-from src.session.IWrappedCallback import IWrappedCallback
-from src.providers.voice.contracts.IChannelPhoneEndpoint import IChannelPhoneEndpoint
+from nerualpha.providers.voice.contracts.IOnInboundCallPayload import IOnInboundCallPayload
+from nerualpha.session.IWrappedCallback import IWrappedCallback
+from nerualpha.providers.voice.contracts.IChannelPhoneEndpoint import IChannelPhoneEndpoint
 
 @dataclass
 class OnInboundCallPayload(IOnInboundCallPayload):
