@@ -2,8 +2,8 @@ from dataclasses import dataclass, field
 from typing import Dict, List, Generic, TypeVar
 from abc import ABC, abstractmethod
 
-from src.providers.voice.contracts.IVapiCreateCallPayload import IVapiCreateCallPayload
-from src.providers.voice.contracts.IPhoneContact import IPhoneContact
+from nerualpha.providers.voice.contracts.IVapiCreateCallPayload import IVapiCreateCallPayload
+from nerualpha.providers.voice.contracts.IPhoneContact import IPhoneContact
 
 @dataclass
 class VapiCreateCallPayload(IVapiCreateCallPayload):
