@@ -2,8 +2,8 @@ from dataclasses import dataclass, field
 from typing import Dict, List, Generic, TypeVar
 from abc import ABC, abstractmethod
 
-from src.providers.voice.contracts.IVapiEventCallBackPayload import IVapiEventCallBackPayload
-from src.session.IWrappedCallback import IWrappedCallback
+from nerualpha.providers.voice.contracts.IVapiEventCallBackPayload import IVapiEventCallBackPayload
+from nerualpha.session.IWrappedCallback import IWrappedCallback
 
 @dataclass
 class VapiEventCallBackPayload(IVapiEventCallBackPayload):
