@@ -2,7 +2,7 @@ from dataclasses import dataclass, field
 from typing import Dict, List, Generic, TypeVar
 from abc import ABC, abstractmethod
 
-from src.session.IWrappedCallback import IWrappedCallback
+from nerualpha.session.IWrappedCallback import IWrappedCallback
 
 T = TypeVar("T")
 
