@@ -2,9 +2,9 @@ from dataclasses import dataclass, field
 from typing import Dict, List, Generic, TypeVar
 from abc import ABC, abstractmethod
 
-from src.session.IActionPayload import IActionPayload
-from src.session.ICommand import ICommand
-from src.session.ICommandHeaders import ICommandHeaders
+from nerualpha.session.IActionPayload import IActionPayload
+from nerualpha.session.ICommand import ICommand
+from nerualpha.session.ICommandHeaders import ICommandHeaders
 
 T = TypeVar("T")
 
