@@ -2,9 +2,9 @@ from dataclasses import dataclass, field
 from typing import Dict, List, Generic, TypeVar
 from abc import ABC, abstractmethod
 
-from src.session.IPayloadWithCallback import IPayloadWithCallback
-from src.session.IActionPayload import IActionPayload
-from src.session.ISession import ISession
+from nerualpha.session.IPayloadWithCallback import IPayloadWithCallback
+from nerualpha.session.IActionPayload import IActionPayload
+from nerualpha.session.ISession import ISession
 
 @dataclass
 class RequestInterfaceForCallbacks:
