@@ -2,8 +2,8 @@ from dataclasses import dataclass, field
 from typing import Dict, List, Generic, TypeVar
 from abc import ABC, abstractmethod
 
-from src.webhookEvents.IUrlObject import IUrlObject
-from src.webhookEvents.messenger.IMessengerVideoEvent import IMessengerVideoEvent
+from nerualpha.webhookEvents.IUrlObject import IUrlObject
+from nerualpha.webhookEvents.messenger.IMessengerVideoEvent import IMessengerVideoEvent
 
 @dataclass
 class MessengerVideoEvent(IMessengerVideoEvent):
