@@ -2,9 +2,9 @@ from dataclasses import dataclass, field
 from typing import Dict, List, Generic, TypeVar
 from abc import ABC, abstractmethod
 
-from src.webhookEvents.whatsapp.IMessageEventContext import IMessageEventContext
-from src.webhookEvents.whatsapp.IProfileName import IProfileName
-from src.webhookEvents.whatsapp.IWhatsappEvent import IWhatsappEvent
+from nerualpha.webhookEvents.whatsapp.IMessageEventContext import IMessageEventContext
+from nerualpha.webhookEvents.whatsapp.IProfileName import IProfileName
+from nerualpha.webhookEvents.whatsapp.IWhatsappEvent import IWhatsappEvent
 
 @dataclass
 class WhatsappEvent(IWhatsappEvent):
