@@ -2,7 +2,7 @@ from dataclasses import dataclass, field
 from typing import Dict, List, Generic, TypeVar
 from abc import ABC, abstractmethod
 
-from src.webhookEvents.whatsapp.IWhatsappTextEvent import IWhatsappTextEvent
+from nerualpha.webhookEvents.whatsapp.IWhatsappTextEvent import IWhatsappTextEvent
 
 @dataclass
 class WhatsappTextEvent(IWhatsappTextEvent):
