@@ -2,7 +2,7 @@ from dataclasses import dataclass, field
 from typing import Dict, List, Generic, TypeVar
 from abc import ABC, abstractmethod
 
-from src.webhookEvents.whatsapp.IWhatsappUnsupportedEvent import IWhatsappUnsupportedEvent
+from nerualpha.webhookEvents.whatsapp.IWhatsappUnsupportedEvent import IWhatsappUnsupportedEvent
 
 @dataclass
 class WhatsappUnsupportedEvent(IWhatsappUnsupportedEvent):
